==> libxkbcommon-doc-1.9.0-1-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/all_a.js <==
var searchData=
[
  ['a_20custom_20configuration_0',['Testing a custom configuration',['../debugging.html#testing-custom-config',1,'']]],
  ['a_20layout_1',['Adding a layout',['../user-configuration.html#user-config-layout',1,'']]],
  ['a_20modifier_2',['Define and use a modifier',['../keymap-text-format-v1.html#define-and-use-a-modifier',1,'']]],
  ['action_3',['action',['../keymap-text-format-v1.html#private-action',1,'Private action'],['../todo.html#_todo000013',1,'Private action'],['../error-index.html#XKB-883',1,'XKB-883 – Conflicting key action']]],
  ['actions_4',['Actions',['../keymap-text-format-v1.html#key-actions-table',1,'']]],
  ['actions_5',['actions',['../keymap-text-format-v1.html#control-flags-actions',1,'Control flags actions'],['../todo.html#_todo000011',1,'Control flags actions'],['../keymap-text-format-v1.html#group-actions',1,'Group actions'],['../todo.html#_todo000009',1,'Group actions'],['../keymap-text-format-v1.html#key-actions',1,'Key actions'],['../todo.html#_todo000005',1,'Key actions'],['../keymap-text-format-v1.html#modifiers-actions',1,'Modifiers actions'],['../todo.html#_todo000006',1,'Modifiers actions'],['../todo.html#_todo000007',1,'Modifiers actions'],['../todo.html#_todo000008',1,'Modifiers actions'],['../keymap-text-format-v1.html#pointer-actions',1,'Pointer actions'],['../todo.html#_todo000010',1,'Pointer actions'],['../keymap-text-format-v1.html#server-actions',1,'Server actions'],['../todo.html#_todo000012',1,'Server actions'],['../keymap-text-format-v1.html#legacy-actions',1,'Unsupported legacy actions']]],
  ['actions_20and_20keysyms_20count_6',['XKB-693 – Incompatible actions and keysyms count',['../error-index.html#XKB-693',1,'']]],
  ['adding_20a_20layout_7',['Adding a layout',['../user-configuration.html#user-config-layout',1,'']]],
  ['adding_20an_20option_8',['Adding an option',['../user-configuration.html#adding-an-option',1,'']]],
  ['additions_9',['Additions',['../xkbcommon-compatibility.html#additions',1,'']]],
  ['additions_10',['Notable additions',['../xkbcommon-compatibility.html#notable-additions',1,'']]],
  ['advanced_20tools_11',['Advanced tools',['../debugging.html#advanced-tools',1,'']]],
  ['alias_12',['XKB-101 – Illegal keycode alias',['../error-index.html#XKB-101',1,'']]],
  ['alias_20statements_13',['Alias statements',['../keymap-text-format-v1.html#keycode-alias',1,'']]],
  ['allocation_20error_14',['XKB-550 – Allocation error',['../error-index.html#XKB-550',1,'']]],
  ['an_20option_15',['Adding an option',['../user-configuration.html#adding-an-option',1,'']]],
  ['and_20client_20state_16',['Server State and Client State',['../group__state.html',1,'']]],
  ['and_20dead_20keys_20support_17',['Compose and dead-keys support',['../group__compose.html',1,'']]],
  ['and_20keysyms_20count_18',['XKB-693 – Incompatible actions and keysyms count',['../error-index.html#XKB-693',1,'']]],
  ['and_20rule_20sets_19',['Rules and rule sets',['../rule-file-format.html#rule-def',1,'']]],
  ['and_20symbols_20',['and symbols',['../rule-file-format.html#rules-options-example',1,'Example: layout, option and symbols'],['../rule-file-format.html#rules-symbols-example',1,'Example: layouts, variants and symbols']]],
  ['and_20use_20a_20modifier_21',['Define and use a modifier',['../keymap-text-format-v1.html#define-and-use-a-modifier',1,'']]],
  ['and_20virtual_20modifiers_22',['Real and virtual modifiers',['../keymap-text-format-v1.html#real-and-virtual-modifiers',1,'']]],
  ['api_23',['API',['../index.html#api',1,'']]],
  ['array_20entry_24',['XKB-077 – Expected array entry',['../error-index.html#XKB-077',1,'']]],
  ['at_20once_25',['XKB-700 – Multiple groups at once',['../error-index.html#XKB-700',1,'']]],
  ['available_20rmlvo_26',['Query for available RMLVO',['../group__registry.html',1,'']]],
  ['available_20tools_27',['Available tools',['../debugging.html#available-tools',1,'']]]
];

==> libxkbcommon-doc-1.9.2-1-x86_64.pkg.tar.zst: usr/share/doc/libxkbcommon/html/search/all_a.js <==
var searchData=
[
  ['a_20custom_20configuration_0',['Testing a custom configuration',['../debugging.html#testing-custom-config',1,'']]],
  ['a_20layout_1',['Adding a layout',['../user-configuration.html#user-config-layout',1,'']]],
  ['a_20modifier_2',['Define and use a modifier',['../keymap-text-format-v1.html#define-and-use-a-modifier',1,'']]],
  ['action_3',['action',['../keymap-text-format-v1.html#private-action',1,'Private action'],['../todo.html#_todo000013',1,'Private action'],['../error-index.html#XKB-883',1,'XKB-883 – Conflicting key action']]],
  ['actions_4',['Actions',['../keymap-text-format-v1.html#key-actions-table',1,'']]],
  ['actions_5',['actions',['../keymap-text-format-v1.html#control-flags-actions',1,'Control flags actions'],['../todo.html#_todo000011',1,'Control flags actions'],['../keymap-text-format-v1.html#group-actions',1,'Group actions'],['../todo.html#_todo000009',1,'Group actions'],['../keymap-text-format-v1.html#key-actions',1,'Key actions'],['../todo.html#_todo000005',1,'Key actions'],['../keymap-text-format-v1.html#modifiers-actions',1,'Modifiers actions'],['../todo.html#_todo000006',1,'Modifiers actions'],['../todo.html#_todo000007',1,'Modifiers actions'],['../todo.html#_todo000008',1,'Modifiers actions'],['../keymap-text-format-v1.html#pointer-actions',1,'Pointer actions'],['../todo.html#_todo000010',1,'Pointer actions'],['../keymap-text-format-v1.html#server-actions',1,'Server actions'],['../todo.html#_todo000012',1,'Server actions'],['../keymap-text-format-v1.html#legacy-actions',1,'Unsupported legacy actions']]],
  ['actions_20and_20keysyms_20count_6',['XKB-693 – Incompatible actions and keysyms count',['../error-index.html#XKB-693',1,'']]],
  ['adding_20a_20layout_7',['Adding a layout',['../user-configuration.html#user-config-layout',1,'']]],
  ['adding_20an_20option_8',['Adding an option',['../user-configuration.html#adding-an-option',1,'']]],
  ['additions_9',['Additions',['../xkbcommon-compatibility.html#additions',1,'']]],
  ['additions_10',['Notable additions',['../xkbcommon-compatibility.html#notable-additions',1,'']]],
  ['advanced_20tools_11',['Advanced tools',['../debugging.html#advanced-tools',1,'']]],
  ['alias_12',['XKB-101 – Illegal keycode alias',['../error-index.html#XKB-101',1,'']]],
  ['alias_20statements_13',['Alias statements',['../keymap-text-format-v1.html#keycode-alias',1,'']]],
  ['allocation_20error_14',['XKB-550 – Allocation error',['../error-index.html#XKB-550',1,'']]],
  ['an_20option_15',['Adding an option',['../user-configuration.html#adding-an-option',1,'']]],
  ['and_20client_20state_16',['Server State and Client State',['../group__state.html',1,'']]],
  ['and_20dead_20keys_20support_17',['Compose and dead-keys support',['../group__compose.html',1,'']]],
  ['and_20keysyms_20count_18',['XKB-693 – Incompatible actions and keysyms count',['../error-index.html#XKB-693',1,'']]],
  ['and_20rule_20sets_19',['Rules and rule sets',['../rule-file-format.html#rule-def',1,'']]],
  ['and_20symbols_20',['and symbols',['../rule-file-format.html#rules-options-example',1,'Example: layout, option and symbols'],['../rule-file-format.html#rules-symbols-example',1,'Example: layouts, variants and symbols']]],
  ['and_20use_20a_20modifier_21',['Define and use a modifier',['../keymap-text-format-v1.html#define-and-use-a-modifier',1,'']]],
  ['and_20virtual_20modifiers_22',['Real and virtual modifiers',['../keymap-text-format-v1.html#real-and-virtual-modifiers',1,'']]],
  ['api_23',['API',['../index.html#api',1,'API'],['../faq.html#api-1',1,'API']]],
  ['are_20the_20keyboard_20layouts_20defined_24',['Where are the keyboard layouts defined?',['../faq.html#where-are-the-keyboard-layouts-defined',1,'']]],
  ['array_20entry_25',['XKB-077 – Expected array entry',['../error-index.html#XKB-077',1,'']]],
  ['as_20expected_26',['Why does my keyboard layout not work as expected?',['../faq.html#why-does-my-keyboard-layout-not-work-as-expected',1,'']]],
  ['asked_20question_20faq_27',['Frequently Asked Question (FAQ)',['../faq.html',1,'']]],
  ['at_20once_28',['XKB-700 – Multiple groups at once',['../error-index.html#XKB-700',1,'']]],
  ['available_20rmlvo_29',['Query for available RMLVO',['../group__registry.html',1,'']]],
  ['available_20tools_30',['Available tools',['../debugging.html#available-tools',1,'']]]
];
